@@ -1,5 +1,3 @@
-from typing import *
-
 from cognite.client.data_classes.assets import (
     AggregateResultItem,
     Asset,
@@ -11,13 +9,22 @@ from cognite.client.data_classes.assets import (
 from cognite.client.data_classes.contextualization import (
     ContextualizationJob,
     ContextualizationJobList,
+    ContextualizationJobType,
     EntityMatchingModel,
     EntityMatchingModelList,
     EntityMatchingModelUpdate,
+    JobStatus,
+)
+from cognite.client.data_classes.extractionpipelines import (
+    ExtractionPipeline,
+    ExtractionPipelineContact,
+    ExtractionPipelineList,
+    ExtractionPipelineRun,
+    ExtractionPipelineRunFilter,
+    ExtractionPipelineRunList,
+    ExtractionPipelineRunUpdate,
+    ExtractionPipelineUpdate,
 )
-from cognite.client.data_classes.data_sets import DataSet, DataSetAggregate, DataSetFilter, DataSetList, DataSetUpdate
-from cognite.client.data_classes.datapoints import Datapoint, Datapoints, DatapointsList, DatapointsQuery
-from cognite.client.data_classes.events import EndTimeFilter, Event, EventFilter, EventList, EventUpdate
 from cognite.client.data_classes.files import (
     FileAggregate,
     FileMetadata,
@@ -46,8 +53,6 @@ from cognite.client.data_classes.labels import (
     LabelDefinitionList,
     LabelFilter,
 )
-from cognite.client.data_classes.login import LoginStatus
-from cognite.client.data_classes.raw import Database, DatabaseList, Row, RowList, Table, TableList
 from cognite.client.data_classes.relationships import (
     Relationship,
     RelationshipFilter,
@@ -57,13 +62,13 @@ from cognite.client.data_classes.relationships import (
 from cognite.client.data_classes.sequences import (
     Sequence,
     SequenceAggregate,
+    SequenceColumnUpdate,
     SequenceData,
     SequenceDataList,
     SequenceFilter,
     SequenceList,
     SequenceUpdate,
 )
-from cognite.client.data_classes.shared import AggregateResult, AggregateUniqueValuesResult, TimestampRange
 from cognite.client.data_classes.templates import (
     ConstantResolver,
     TemplateGroup,
@@ -94,3 +99,21 @@ from cognite.client.data_classes.time_series import (
     TimeSeriesList,
     TimeSeriesUpdate,
 )
+
+from cognite.client.data_classes.data_sets import (  # isort: skip
+    DataSet,
+    DataSetAggregate,
+    DataSetFilter,
+    DataSetList,
+    DataSetUpdate,
+)
+from cognite.client.data_classes.shared import (  # isort: skip
+    AggregateResult,
+    AggregateUniqueValuesResult,
+    TimestampRange,
+)
+
+from cognite.client.data_classes.datapoints import Datapoint, Datapoints, DatapointsList, DatapointsQuery  # isort: skip
+from cognite.client.data_classes.events import EndTimeFilter, Event, EventFilter, EventList, EventUpdate  # isort: skip
+from cognite.client.data_classes.login import LoginStatus  # isort: skip
+from cognite.client.data_classes.raw import Database, DatabaseList, Row, RowList, Table, TableList  # isort: skip
